from .server import Data as db

class Ring(db):
    pass